package com.bonus.material.purchase.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.material.purchase.domain.PurchaseMacodeInfo;
import com.bonus.material.purchase.service.IPurchaseMacodeInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 新购验收编号管理Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "新购验收编号管理接口")
@RestController
@RequestMapping("/purchase_macode_info")
public class PurchaseMacodeInfoController extends BaseController {

    @Autowired
    private IPurchaseMacodeInfoService purchaseMacodeInfoService;

    /**
     * 查询新购验收编号管理列表
     */
    @ApiOperation(value = "查询新购验收编号管理列表")
    //@RequiresPermissions("purchase:info:list")
    @GetMapping("/list")
    public  AjaxResult list(PurchaseMacodeInfo purchaseMacodeInfo) {
//        startPage();
        List<PurchaseMacodeInfo> list = purchaseMacodeInfoService.selectPurchaseMacodeInfoList(purchaseMacodeInfo);
        return success(list);
    }

    /**
     * 导出新购验收编号管理列表
     */
    @ApiOperation(value = "导出新购验收编号管理列表")
    @PreventRepeatSubmit
    //@RequiresPermissions("purchase:info:export")
    @SysLog(title = "新购验收编号管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出新购验收编号管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PurchaseMacodeInfo purchaseMacodeInfo) {
        List<PurchaseMacodeInfo> list = purchaseMacodeInfoService.selectPurchaseMacodeInfoList(purchaseMacodeInfo);
        ExcelUtil<PurchaseMacodeInfo> util = new ExcelUtil<PurchaseMacodeInfo>(PurchaseMacodeInfo.class);
        util.exportExcel(response, list, "新购验收编号管理数据");
    }

    /**
     * 获取新购验收编号管理详细信息
     */
    @ApiOperation(value = "获取新购验收编号管理详细信息")
    //@RequiresPermissions("purchase:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(purchaseMacodeInfoService.selectPurchaseMacodeInfoById(id));
    }

    /**
     * 新增新购验收编号管理
     */
    @ApiOperation(value = "新增新购验收编号管理")
    @PreventRepeatSubmit
    //@RequiresPermissions("purchase:info:add")
    @SysLog(title = "新购验收编号管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增新购验收编号管理")
    @PostMapping
    public AjaxResult add(@RequestBody PurchaseMacodeInfo purchaseMacodeInfo) {
        try {
            return toAjax(purchaseMacodeInfoService.insertPurchaseMacodeInfo(purchaseMacodeInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改新购验收编号管理
     */
    @ApiOperation(value = "修改新购验收编号管理")
    @PreventRepeatSubmit
    //@RequiresPermissions("purchase:info:edit")
    @SysLog(title = "新购验收编号管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改新购验收编号管理")
    @PutMapping
    public AjaxResult edit(@RequestBody PurchaseMacodeInfo purchaseMacodeInfo) {
        try {
            return toAjax(purchaseMacodeInfoService.updatePurchaseMacodeInfo(purchaseMacodeInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除新购验收编号管理
     */
    @ApiOperation(value = "删除新购验收编号管理")
    @PreventRepeatSubmit
//    @RequiresPermissions("purchase:info:remove")
    @SysLog(title = "新购验收编号管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除新购验收编号管理")
	@PostMapping("/un_bind")
    public AjaxResult unBind(@RequestBody List<Integer> ids) {
        return toAjax(purchaseMacodeInfoService.deletePurchaseMacodeInfoByIds(ids));
    }
}
